==> haskell-sendfile-0.7.11.4-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sendfile
version:              0.7.11.4
visibility:           public
id:                   sendfile-0.7.11.4-8ZxolGeX3mU97oQqAHjYZk
key:                  sendfile-0.7.11.4-8ZxolGeX3mU97oQqAHjYZk
license:              BSD-3-Clause
maintainer:           Jeremy Shaw <jeremy@n-heptane.com>
author:               Matthew Elder <matt@mattelder.org>
stability:            provisional
homepage:             https://github.com/Happstack/sendfile
synopsis:             A portable sendfile library
description:
    A library which exposes zero-copy sendfile functionality in a portable way. If a platform does not support sendfile, a fallback implementation in haskell is provided.

    Currently supported platforms: Windows 2000+ (Native), Linux 2.6+ (Native), FreeBSD (Native), OS-X 10.5+ (Native), Everything else (Portable Haskell code).

category:             Network
abi:                  1eeb351f4fb1c2144fddc7e499bbdf09
exposed:              True
exposed-modules:
    Network.Socket.SendFile Network.Socket.SendFile.Handle
    Network.Socket.SendFile.Iter Network.Socket.SendFile.Portable

hidden-modules:
    Network.Socket.SendFile.Internal Network.Socket.SendFile.Util
    Network.Socket.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.0.2/site-local/sendfile-0.7.11.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/sendfile-0.7.11.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sendfile
hs-libraries:         HSsendfile-0.7.11.4-8ZxolGeX3mU97oQqAHjYZk
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    network-3.1.2.7-3dAlKyu2TU91rkKNmDqxd9

haddock-interfaces:   /usr/share/doc/haskell-sendfile/html/sendfile.haddock
haddock-html:         /usr/share/doc/haskell-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sendfile-0.7.11.4-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sendfile
version:              0.7.11.4
visibility:           public
id:                   sendfile-0.7.11.4-6WLHSGEP1zn2qsq8R7XgT9
key:                  sendfile-0.7.11.4-6WLHSGEP1zn2qsq8R7XgT9
license:              BSD-3-Clause
maintainer:           Jeremy Shaw <jeremy@n-heptane.com>
author:               Matthew Elder <matt@mattelder.org>
stability:            provisional
homepage:             https://github.com/Happstack/sendfile
synopsis:             A portable sendfile library
description:
    A library which exposes zero-copy sendfile functionality in a portable way. If a platform does not support sendfile, a fallback implementation in haskell is provided.

    Currently supported platforms: Windows 2000+ (Native), Linux 2.6+ (Native), FreeBSD (Native), OS-X 10.5+ (Native), Everything else (Portable Haskell code).

category:             Network
abi:                  c0ed03c3a53483a4eeb55c0ae60591bb
exposed:              True
exposed-modules:
    Network.Socket.SendFile Network.Socket.SendFile.Handle
    Network.Socket.SendFile.Iter Network.Socket.SendFile.Portable

hidden-modules:
    Network.Socket.SendFile.Internal Network.Socket.SendFile.Util
    Network.Socket.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.0.2/site-local/sendfile-0.7.11.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/sendfile-0.7.11.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sendfile
hs-libraries:         HSsendfile-0.7.11.4-6WLHSGEP1zn2qsq8R7XgT9
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    network-3.1.2.7-3MnWjnNhABh27tP7sbt8Ba

haddock-interfaces:   /usr/share/doc/haskell-sendfile/html/sendfile.haddock
haddock-html:         /usr/share/doc/haskell-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
